@@ -10,7 +10,7 @@
 # }
 #
 # \arguments{
-#  \item{colClasses}{A @character @vector of column classes, 
+#  \item{colClasses}{A @character @vector of column classes,
 #    cf. @see "utils::read.table".}
 #  \item{nrow}{An @integer specifying the number of rows of the
 #    allocated data frame.}
@@ -37,21 +37,13 @@
 # @keyword utilities
 #*/###########################################################################
 setMethodS3("dataFrame", "default", function(colClasses, nrow=1, ...) {
-  df <- vector("list", length=length(colClasses));
-  names(df) <- names(colClasses);
-  for (kk in seq(along=df)) {
-    df[[kk]] <- vector(colClasses[kk], length=nrow);
+  df <- vector("list", length=length(colClasses))
+  names(df) <- names(colClasses)
+  for (kk in seq_along(df)) {
+    df[[kk]] <- vector(colClasses[kk], length=nrow)
   }
 
-  attr(df, "row.names") <- seq(length=nrow);
-  class(df) <- "data.frame";
-  df;
+  attr(df, "row.names") <- seq_len(nrow)
+  class(df) <- "data.frame"
+  df
 }, private=TRUE)
-
-##############################################################################
-# HISTORY:
-# 2007-11-25
-# o Added Rdoc comments.
-# 2006-11-22
-# o Created.
-##############################################################################
